.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.ui
-------------------

.. automodule:: reahl.web.ui


Widgets for constructing a main window
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

HTML5Page
"""""""""

.. autoclass:: HTML5Page
   :members:

TwoColumnPage
"""""""""""""

.. autoclass:: TwoColumnPage
   :members:

Slot
""""

.. autoclass:: Slot
   :members:

RunningOnBadge
""""""""""""""

.. autoclass:: RunningOnBadge
   :members:


Very low-level Widgets that correspond to HTML 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

HTMLElement
"""""""""""

.. autoclass:: HTMLElement
   :members:

TextNode
""""""""

.. autoclass:: Title
   :members:

Title
"""""

.. autoclass:: Title
   :members:

Link
""""

.. autoclass:: Link
   :members:

Head
""""

.. autoclass:: Head
   :members:

Body
""""

.. autoclass:: Body
   :members:

Span
""""

.. autoclass:: Span
   :members:

More commonly used Widgets that correspond to HTML 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

A
"

.. autoclass:: A
   :members:

H
"

.. autoclass:: H
   :members:

P
"

.. autoclass:: P
   :members:
  
Div
"""

.. autoclass:: Div
   :members:
  
Nav
"""

.. autoclass:: Nav
   :members:

Article
"""

.. autoclass:: Article
   :members:

Header
""""""

.. autoclass:: Header
   :members:

Footer
""""""

.. autoclass:: Footer
   :members:

Li
""

.. autoclass:: Li
   :members:

Ul
""

.. autoclass:: Ul
   :members:

Img
"""

.. autoclass:: Img
   :members:

Widgets for Input
^^^^^^^^^^^^^^^^^

Form
""""

.. autoclass:: Form
   :members:

NestedForm
""""""""""

.. autoclass:: NestedForm
   :members:

InputGroup
""""""""""

.. autoclass:: InputGroup
   :members:

FieldSet
""""""""

.. autoclass:: FieldSet
   :members:

Input
"""""

.. autoclass:: Input
   :members:

TextArea
""""""""

.. autoclass:: TextArea
   :members:


SelectInput
"""""""""""

.. autoclass:: SelectInput
   :members:
   

RadioButtonInput
""""""""""""""""

.. autoclass:: RadioButtonInput
   :members:
   
TextInput
"""""""""

.. autoclass:: TextInput
   :members:

PasswordInput
"""""""""""""

.. autoclass:: PasswordInput
   :members:

CheckboxInput
"""""""""""""

.. autoclass:: CheckboxInput
   :members:
   
Button
""""""

.. autoclass:: Button
   :members:
   

InputLabel
""""""""""

.. autoclass:: InputLabel
   :members:

ErrorLabel
""""""""""

.. autoclass:: ErrorLabel
   :members:


Widgets to help with layout of Inputs
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

LabelledInlineInput
"""""""""""""""""""

.. autoclass:: LabelledInlineInput
   :members:
   
LabelledBlockInput
""""""""""""""""""

.. autoclass:: LabelledBlockInput
   :members:

CueInput
""""""""

.. autoclass:: CueInput
   :members:

LabelOverInput
""""""""""""""

.. autoclass:: LabelOverInput
   :members:


Menus
^^^^^

MenuItem
""""""""

.. autoclass:: MenuItem
   :members:

Menu
""""

.. autoclass:: Menu
   :members:
   
SubMenu
"""""""

.. autoclass:: SubMenu
   :members:
   

HMenu
"""""

.. autoclass:: HMenu
   :members:


VMenu
"""""

.. autoclass:: VMenu
   :members:


Tabbed or sliding panels
^^^^^^^^^^^^^^^^^^^^^^^^

Tab
"""

.. autoclass:: Tab
   :members:

MultiTab
""""""""

.. autoclass:: MultiTab
   :members:

TabbedPanel
"""""""""""

.. autoclass:: TabbedPanel
   :members:

SlidingPanel
""""""""""""

.. autoclass:: SlidingPanel
   :members:


Uploading of files
^^^^^^^^^^^^^^^^^^

SimpleFileInput
"""""""""""""""

.. autoclass:: SimpleFileInput
   :members:

FileUploadInput
"""""""""""""""

.. autoclass:: FileUploadInput
   :members:

Support for Yui 2 CSS Grids
^^^^^^^^^^^^^^^^^^^^^^^^^^^


YuiDoc
""""""

.. autoclass:: YuiDoc
   :members:

YuiUnit
"""""""

.. autoclass:: YuiUnit
   :members:

YuiGrid
"""""""

.. autoclass:: YuiGrid
   :members:

YuiBlock
""""""""

.. autoclass:: YuiBlock
   :members:


Misc
^^^^

Panel
"""""

.. autoclass:: Panel
   :members:

LiteralHTML
"""""""""""

.. autoclass:: LiteralHTML
   :members:

PriorityGroup
"""""""""""""

.. autoclass:: PriorityGroup
   :members:

ErrorFeedbackMessage
""""""""""""""""""""

.. autoclass:: ErrorFeedbackMessage
   :members:

